#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSIVBSuIOmSoThZERR21CkWoEGqFVh1MXn+hSUOS4uIouBYc/FmsOrg4'
    b'6+rgKgiCPyBubk6KLlLifUmhRYwXHu/jvHsO790HCLUSU822MUDVLCMRi4qp9KoYeIUPPejD'
    b'NAZlZupzkhSHZ33dUzfVXYRneff9WV2ZrMkAn0g8y3TDIt4gntq0dM77xCFWkDPE58SjBl2Q'
    b'+JHristvnPMOCzwzZCQT88QhYjHfwkoLs4KhEk8ShzOqRvlCyuUM5y3OaqnCGvfkLwxmtZVl'
    b'rtMaQgyLWIIEEQoqKKIECxHaNVJMJOg86uEfcPwSuRRyFcHIsYAyVMiOH/wPfs/WzE2Mu0nB'
    b'KND+Ytsfw0BgF6hXbfv72LbrJ4D/GbjSmv5yDZj5JL3a1MJHQPc2cHHd1JQ94HIH6H/SZUN2'
    b'JD8tIZcD3s/om9JA7y3QuebOrXGO0wcgSbOK3wAHh8BInrLXPd7d0Tq3f3sa8/sBmGhytoLJ'
    b'W7wAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxIAAAsSAdLdfvwAAAAHdElNRQflARAV'
    b'ORDu+qL7AAAAZUlEQVQoz6WSwQ3AMAgDHcQS3aajZxvGoJ9WSktAMvUPibNNFOCHxmd2Zj/A'
    b'0/b8eYzACFPzNvYWvKQ7ACiZ+jKRKmVJ2koycJpjmpcGwtSlYbp28sJBmlV9oKq2dm7t/u2K'
    b'5XQBrCMgHHCHIN4AAAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kTtIw1AUhv+miiKVInYQcchQnSyIiuimVShChVArtOpgctMXNGlIUlwcBdeCg4/FqoOL'
    b's64OroIg+ABxc3NSdJESz00KLWI8cLgf/z3/4dxzAaFeZprVMQZoum2mEnExk10Vu14RQB9l'
    b'GDMys4w5SUrCN77uqZLiLsZ7+df9Gb1qzmJAQCSeZYZpE28QT23aBud94ggryirxOfGoSQMS'
    b'P3Jd8fiNc8FlgfeMmOnUPHGEWCy0sdLGrGhqxJPEUVXTqb+Q8VjlvMVZK1dZc07+wlBOX1nm'
    b'OuUQEljEEiSIUFBFCWXYiNGpk2IhRfdxH/+g65fIpZCrBEaOBVSgQXb94H/we7dWfmLc6xSK'
    b'A50vjvMxDHTtAo2a43wfO07jBAg+A1d6y1+pA9OfpNdaWvQICG8DF9ctTdkDLneAgSdDNmVX'
    b'ClIK+TzwfkbflAX6b4GeNW9vzXucPgBp2lXyBjg4BEYK1Hvd593d7Xv7t6a5vx9PpXKZcf7U'
    b'MwAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAAd0SU1FB+UBEQER'
    b'IDbtUDQAAAA9SURBVDjLY2AYBaSA/9gEGck0gJEsA/7/h5jByIjQz4jLaThMQHU+IyMDCwmu'
    b'+I+sEdkFFIUBxbEwCqgAAG+sDQpZORdGAAAAAElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDE2IEF1ZyAyMDA1IDEzOjU3OjUwICswMTAw0YaYRwAAAAd0SU1FB9MCGxAGHYzcL/AA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAACO0lEQVR42qWSXUgUURTH'
    b'/3d2ZsfWbDfSPiwqzAo1LKKiaF8s0AiCIsinHgz7WoMeAoMKoVyCfJHood1KRHqIQM0tF6uX'
    b'etLt81XXRJPYXd11Rmd3xmn2w9MoWA+5ttAfzuFeuPfHOf9zgP8UWzxIUzHhVY+vMZFOnefz'
    b'V2/WlOm4GhrrJt5663azO7wsYDgY5AOBQG9h5f6aHXvKIOtARANikzJF/O1hXY46795r+b4U'
    b'gJtPnwIDDfaKfTVO8/Na856XScOi6+AEG3Mcd20UraInWwULAEkz6ooryjEbCUE3w5gIgZfC'
    b'EGPjYBwPvmRv9cX6c8VLAfj5RPmrSmUVCO7ehNkMoKUB1Yx4CnD0jSBv3VamTE9vM5+GlwQk'
    b'E4o0oVJ+gX8YsW9DSKYJMINLZqDLU+DIAGNMylqBGh7ttUzJLkXcAEtZIYQ5QipFcBBD3koH'
    b'JF/LyLPO7sGsHsAiNKvvOiLxJEfxjAg9zcMmroBgs2P2s48MeXL9g47nb1+eOWTLugc3rjdu'
    b't4rCU1Zy8IBYtIVSmgJ98P1EPPJDcLd6i748uYKqvrYeNvqzlpld/gVY1KX6ukplZqbUSKak'
    b'/g8fB67dvOPZSUN1J44owKBpQ1fAj0D0NBuHkdOqXm5qsKer0E7t1UTDV4k6TxLVrnlD5bDl'
    b'BFgYs+kVnSp4TI+OmhAXaV1nqanVG/xj4j9k9jmHF4kL8Pd79NdBRJ33wRLS199jzBFC5NNd'
    b'7sPHdlm8D8fkyXBbzi0sp1+5mvzKqKC80wAAAABJRU5ErkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADr3pUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7VZbsuMoDP3XKmYJlsRDLAeDqZod9PLngO3cOLGT3On701VtYh5CHCQd'
    b'gUPLr38b/YNHRIycjxZSCBMel1ySjI5N65NHzZMb9Xhkm8L4IKfbhECkaHUdWtj0dznfANYm'
    b'o+fvgKxsE/NxIrkN3x6Atp21W9T7dQNKG5DKOsEbQF7dmkKyeO/CvKxt3T2x9aVeOTua/TSO'
    b'iF712EdFFmWdUIvKaoD2l0kzOoxa1Env9b5H6XXawBCQszhNd1bRIyu3Hl/IH0jRsMoJgmMw'
    b'w609lbN/kG+ANEJ8t7OW284HeZQpPrqzv61Vo9aW1bvsAkIaNqd2V0YPijNCrmNZQIl4Pfpx'
    b'lIRihOwtoLxOZZpRCicW0NLYceXMjZfRFi4w0ckiMA1HooCoLjONkqToRGDJ9cJNoiatauCv'
    b'gF6FVG628Ng3je0KGzauDE1hgHFPBerVT5RLoNZ6yjNPdosV7JKehDCjM9draIEQbnse+RHg'
    b'vTw+nVcFg36E2eBgnuYVYva85VbPIx1EKxQ92vWscawbAEKEvT2MQdY7ngKr58DIB4nMiKOB'
    b'nwwg62djBgXsvVRYKU41gByTvjfWRB664mUV484CEV6DRlCTNIMrh4sN+ROdIYcyjpjz3gcf'
    b'vfnkc9Dggg8hxNAvvxw1uuhjiDFaTDGbmjNvwaIZWbKcJCkuR59CislSSjlj0wzkjNUZCjnP'
    b'MuvsZj+HOc42pzkXpE9xxZdQYjEqqeQqVSvuiRpqrFZTzQsvSKXFLX4JS1xsSUtuSLWmzTXf'
    b'QovNWmr5xhrTSutT+Zw13lmTwVRXjDfWsDTGHYL7deI7Z2BMHIPx2BlAQkvnbDJ2TqhT1zmb'
    b'kuBUeIGVvpNTuTMGBt3C4hvfuPti7sAbOfdbvMnOHHXqfoI56tRdMPfM2wlrtX9tyqQ0GOrH'
    b'sAd1Uhw/KGUx/PBN+ryl7y74A4Ca9c+60tIQkf4d7jM6Ro/Kx9mTUZvbQuf4r5Z8wzXd15ws'
    b'vpqjdwunYeQMo7buIQBfK+m1wZ+0KxjtdjxF5rVzPZxDuo7mhYbJ90baKweu7afvOXBtI32X'
    b'nSsC6HsOHHXu40rvOLuL3UvpVx7tpl6Nn8AODgq9W7aTfUR4du48Id8e0+cRfa76ekSXk+8T'
    b'7N5B5NG7IH84pt8F+Mrstws+uG1Pbsj/3dJFLl/se52c9BPWnACdXFonu3/o2o/F6C/QX6BP'
    b'vnQN/yAT/QfFhVT0iscGGwAAAYVpQ0NQSUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU0WRiogd'
    b'ijhkqE4WREUdtQpFqBBqhVYdTF76B00akhQXR8G14ODPYtXBxVlXB1dBEPwBcXNzUnSREu9L'
    b'Ci1ivPB4H+fdc3jvPkCol5lmdYwBmm6bqURczGRXxa5XBBBBP6YRkZllzElSEr71dU/dVHcx'
    b'nuXf92f1qjmLAQGReJYZpk28QTy1aRuc94nDrCirxOfEoyZdkPiR64rHb5wLLgs8M2ymU/PE'
    b'YWKx0MZKG7OiqRFPEkdVTad8IeOxynmLs1ausuY9+QtDOX1lmeu0hpDAIpYgQYSCKkoow0aM'
    b'dp0UCyk6j/v4B12/RC6FXCUwciygAg2y6wf/g9+ztfIT415SKA50vjjOxzDQtQs0ao7zfew4'
    b'jRMg+Axc6S1/pQ7MfJJea2nRI6BvG7i4bmnKHnC5A0SeDNmUXSlIS8jngfcz+qYsMHAL9Kx5'
    b'c2ue4/QBSNOskjfAwSEwUqDsdZ93d7fP7d+e5vx+AJsFcrcY3lRgAAAPoGlUWHRYTUw6Y29t'
    b'LmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpy'
    b'ZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4'
    b'bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJodHRw'
    b'Oi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRlc2Ny'
    b'aXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMub3Jn'
    b'L3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9ucy5h'
    b'ZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBsdXM9'
    b'Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1QPSJo'
    b'dHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3Jn'
    b'L2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUuY29t'
    b'L3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4w'
    b'LyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOjFlYWQxOGVhLTEwZDQt'
    b'NDdjNy1iMGI5LWM0MGRlM2UwODZmYiIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo3'
    b'ZGUwM2VlNC05YTYxLTQwNWUtYjBjMC05ZDQ1Y2Y3ODY5OGQiCiAgIHhtcE1NOk9yaWdpbmFs'
    b'RG9jdW1lbnRJRD0ieG1wLmRpZDo3ZTMxYTFlNi02NDZlLTQ3OWMtYjg4Zi0xZTFkMjIzOWJl'
    b'MWYiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAgR0lN'
    b'UDpUaW1lU3RhbXA9IjE2MTE1MTA5NjIxMTcxNTAiCiAgIEdJTVA6VmVyc2lvbj0iMi4xMC4y'
    b'MiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEiCiAg'
    b'IHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25DcmVh'
    b'dGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICA8'
    b'aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9j'
    b'YXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpCYWcv'
    b'PgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3RyeUlk'
    b'PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1NOkhp'
    b'c3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlvbj0i'
    b'c2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNlSUQ9'
    b'InhtcC5paWQ6NTk5ZTU4YzYtYmIxMy00YzYxLTg2OGYtMDc5OWJmMWVhNDZkIgogICAgICBz'
    b'dEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0Ondo'
    b'ZW49IjIwMjEtMDEtMjRUMTE6NTY6MDItMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAgPC94'
    b'bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEvPgog'
    b'ICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAgPHJk'
    b'ZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRPd25l'
    b'cj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1czpM'
    b'aWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRmOkRl'
    b'c2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'CiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAog'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+13bj'
    b'LwAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UBGBE4'
    b'AsblYsEAAACCSURBVFjD7ZQ7DsAgDENjxP2v7C4dEKLlF8hiL4gEKY/EYCZJwcK7shGzRm70'
    b'DGYgOLmvY9zpQIoeQV7sErwBOOiVEsgFIhUF4HmzUW+c9gB7IB4ewE8eFQRuGpwf3WAUQBME'
    b'h4l6LWf4RxQ+ghwEhNln6F7YLrxLXqqz9xVLkiRJD8kaJA6UusFqAAAAAElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAA9dpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYwIDYxLjEzNDc3NywgMjAxMC8wMi8xMi0xNzozMjowMCAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wUmlnaHRzPSJo'
    b'dHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvcmlnaHRzLyIgeG1sbnM6eG1wTU09Imh0dHA6'
    b'Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9tbS8iIHhtbG5zOnN0UmVmPSJodHRwOi8vbnMuYWRv'
    b'YmUuY29tL3hhcC8xLjAvc1R5cGUvUmVzb3VyY2VSZWYjIiB4bWxuczp4bXA9Imh0dHA6Ly9u'
    b'cy5hZG9iZS5jb20veGFwLzEuMC8iIHhtcFJpZ2h0czpNYXJrZWQ9IkZhbHNlIiB4bXBNTTpP'
    b'cmlnaW5hbERvY3VtZW50SUQ9ImFkb2JlOmRvY2lkOnBob3Rvc2hvcDo4ZTMyMGZhYy0xMDU3'
    b'LTExZGItYTlkNC1mZTk0NmM0OWUxNTciIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6RTFB'
    b'NUY3REJGM0I0MTFFNkEzNDlGNjRCNEQ1RDgxRDEiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5p'
    b'aWQ6RTFBNUY3REFGM0I0MTFFNkEzNDlGNjRCNEQ1RDgxRDEiIHhtcDpDcmVhdG9yVG9vbD0i'
    b'QWRvYmUgUGhvdG9zaG9wIENTNSBXaW5kb3dzIj4gPHhtcE1NOkRlcml2ZWRGcm9tIHN0UmVm'
    b'Omluc3RhbmNlSUQ9InhtcC5paWQ6MjhGQjk3NTU5N0YzRTYxMTk1QkZFNzg5RjBFRkJDN0Ei'
    b'IHN0UmVmOmRvY3VtZW50SUQ9ImFkb2JlOmRvY2lkOnBob3Rvc2hvcDo4ZTMyMGZhYy0xMDU3'
    b'LTExZGItYTlkNC1mZTk0NmM0OWUxNTciLz4gPC9yZGY6RGVzY3JpcHRpb24+IDwvcmRmOlJE'
    b'Rj4gPC94OnhtcG1ldGE+IDw/eHBhY2tldCBlbmQ9InIiPz59cfg6AAACV0lEQVR42oyTS0wT'
    b'QRzGv5ndZdtSWmhLLLU0hFRSg2AIJ3zEejKePWji3eDNqweIB2IiXky8cEJiokb0KokHEkPU'
    b'pBdfREzrgzaRNlLY0t1uy27bHWervLQQdvPfncl8+5tvNt+fMMZ8lUplql6vewAGPm8Uf0Av'
    b'l5HPr73o7++/LwgCml2Ei0OKoiRNw3AzG2BZsOxiVmOcTmcgStLYyMipCRv69snjO92hkBU6'
    b'feaWJMuGDegqFAqLHODfBrA/ED5FoaAgm82hzeO5QQXqWp6dvf09maxcn3kYDnR2KmJTX2xn'
    b'aIMcDgc0rXSvqJpMPzEE19HwnP2xvU6bH+wvhzvxer0IR3rh0ecx1DNHVlc+VzfK+t0taXMH'
    b'u4wIkhPFzEcE2xfgd+o46Tk2Pnx5KrGloQcBCL9r1Ro2fz5CJEbw5Z2/FB28MN0VPIJDABio'
    b'5ML613n0RlPI/jDhjIzWYudH2W7VvgBCRFSKCkT9GXxBisxyDL7oObLzhw4C8D2I6ISSeo6+'
    b'gXV8+wS4eq5CEP+XNwVQsQVaLoV2+WWDtqaeRXv3IKyacThA3aIopp+ib3ATyfcu+GJXeCCM'
    b'vQHZD0AoRaW0gexaEYk3EszWS2j1h3hCq/8efzsHRJblFjs0dhNRKkLHL1gmgypdw8DwRb5x'
    b'FYLDyRMp2/raHsDS0lI9n88nebd12ABBENnih0SbuRmhEeqnrxdeMbs3CCEwDVOffjBzvFQq'
    b'5eLx+Mrk5KQhut3uvKZpcQ5o+FNVld0cm/CrqtZRr5mBJr5beYUDgcAqfxu/BRgAJ9ARQuBm'
    b'0B0AAAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAAXNSR0IArs4c6QAAADhlWElm'
    b'TU0AKgAAAAgAAYdpAAQAAAABAAAAGgAAAAAAAqACAAQAAAABAAAAIKADAAQAAAABAAAAIAAA'
    b'AACPTkDJAAAAoUlEQVRYCe1R7QrAIAhse/933uaPAxHFstr244SQzPvgao3FBJjAjxO4Hm9y'
    b'ttYRsFvhaC+A9489YisONm8Xb+VuSSNxCNh9zMtdE2biENEYzModZL3iEAIO93IXolHxspgH'
    b'PL3hm7PPDeAvR78BuOmwNFGvCY1ZakDIMhNLxUXQI4xMeLvCMVURqTUR7U2JZ2AxYY1kGL4z'
    b'ASbABJjAcAI34/cPC7xdKCUAAAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSKVChYRcchQnSyIijhqFYpQIdQKrTqYvPRHaNKQpLg4Cq4FB38Wqw4u'
    b'zro6uAqC4A+Im5uToouUeF9SaBHjhcf7OO+ew3v3AUK9zDSrYwzQdNtMJxNiNrcihl4RQC/6'
    b'EUFIZpYxK0kp+NbXPXVT3cV5ln/fn9Wj5i0GBETiGWaYNvE68dSmbXDeJ46ykqwSnxOPmnRB'
    b'4keuKx6/cS66LPDMqJlJzxFHicViGyttzEqmRjxJHFM1nfKFrMcq5y3OWrnKmvfkLwzn9eUl'
    b'rtMaQhILWIQEEQqq2EAZNuK066RYSNN5wsc/6Polcink2gAjxzwq0CC7fvA/+D1bqzAx7iWF'
    b'E0Dni+N8DAOhXaBRc5zvY8dpnADBZ+BKb/krdWD6k/RaS4sdAZFt4OK6pSl7wOUOMPBkyKbs'
    b'SkFaQqEAvJ/RN+WAvluge9WbW/Mcpw9AhmaVugEODoGRImWv+by7q31u//Y05/cDBU1ye/Jw'
    b'OsYAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxIAAAsSAdLdfvwAAAAHdElNRQflARAW'
    b'Dza3rQgqAAAAWUlEQVQoz2NgoAAwovH/k6IeQ/OB59j1O0gyYuhhIsWZUIP/k6UZyfb/DAwM'
    b'DCwk2opiCBMloc1EwHkobKI0U2QzXTSz4ApZmF9xJRq8UYVPE7lpG59e0gAASEIXHOpnuVMA'
    b'AAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAKnRFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDQgTXJ6IDIwMDMgMTk6MTg6MDUgKzAxMDDiemgrAAAAB3RJTUUH0wgNDSQH/TCwawAA'
    b'AAlwSFlzAAAK8AAACvABQqw0mAAAAARnQU1BAACxjwv8YQUAAAIHSURBVHjarZJNaBNBFMf/'
    b'6bpbk6VFt0loWk9tCOQgxILaGERQCl5UxJOhFxEPXrzorVAxYC+FCnqwXoqHngoVC0KlFFEE'
    b'D1Wh7aGSomD9oNKPdJOYdTv7Mc7MdptAEyjog7ez++a93/vP2wH+0QL7TfzwEDObv9HnugD3'
    b'ko6xqyO4vu9Or4ZhEGOT+jY1CMrjBxoV5J8is1XEOZei1yKIUjmsyEFtT94ewNwj5CXtWIKo'
    b'MXQcTSPcdQFKSxSSpLLdVeYm84g4Rl2AQZA4k30D21yCoX+H/nMK2+U1gBLYNkH89B2WFYTj'
    b'1ADePmiyILdKHalbga/vcjAKC6gUpiEfVKEdOYzmUCebnIlfywsglU9Q1NSugib+sGxaOXlt'
    b'JtCVuS02QloMkXgfDsVOoFmNC8kItKM9cRZ/ykH2rSDd/6yqwKXSsr66cjzS3blDrjDJZdz9'
    b'2Ibc/Km6Q76p/agBOPb8ytxoKtLdIwuAs8WCrV7xxkZdwGNkagAuZgufX1+xjbwmhmPpTIE3'
    b'36XL62LlccvyVtsG0ovhKuD8ACZeDsnZ9xP3LwkFhClASCQkk0lxLF5EiAfh71isGSI3sm1O'
    b'l9a/OALgFvkPFXGe7Dvv7sN82wVcvIcnihoVSebaLErFNg9Mqp39Ykob3MQWSbnxrYyRydEX'
    b'eqY/W2Kh5+o4Bhvc9hz+h/0FAjroo1wrUa4AAAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AFNvIDE3IE5vdiAyMDAyIDE5OjE3OjQ2ICswMTAwQcC18QAAAAd0SU1FB9MCGhEmLPH4BjoA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAACh0lEQVR42qWTu2sUURTG'
    b'v7nzfiSbYd8bFhUJhGBEiELAJpWQQlCIkFKwsUsXGwtBLSz8EwTBThCxTKE2Fgq+goriA9xk'
    b'l2QTQ9jNkt3ZuXeuZ+7Krn1muPO653zn9517BzjioaUXZ+XjnV6jfeP2JctYmhtDxNVncB6D'
    b'xzFiGr2oDyY5Xnzt4O6rkLtR61736cWbLA0Urc4qPq8bXnSI6ekZZMMMEt6HTjqmocOxLRTz'
    b'WZw9cwphxkGu+9owZbKa5hoKg2kmXBtiAIRSsQDfc6FpGvr9viJQREJACA73xDyib1vmSCBN'
    b'tOhRChX4u7aBRqMBxhQgkiRBEAQ4VikQbgJm+9D4QHQgMGBFLBN6i1HI5xBOZCClpIqCesHV'
    b'PRWSiSRiqvWPdkigk09JAYKQa5t17DSbiiC1kUZ4ZKlazpFNCaanZHIkIOm0HAOmTtNRGyfK'
    b'GZyshERAPIQqiKAX9QCaM2klDCLWBgAjC75n4PE7jrUvbyBkWkVLa9Gd5DWmquo6CeoTsE0N'
    b'ysdQQGqwHRP1joafbYZIUAL1xKDBTB06o0FJ454Ji2w5ZtqE/yxQIRiWjkQauFDt4PpCiN29'
    b'fWw2tpWY5brIT/i49WwDMlNE6fTcsIlscGFUjfho05RDA4+et7H8QOLTYRWL81NYXjyPq8uX'
    b'gSAPrzqLmUkPXK3Y0EICkyyYXIfoHqAPG24mwHg2QKmcRbZUoaiICCmJeiPIMm2+EUFvjz/c'
    b'P0jgjnkw0YX0fRilHMbzBVSOT6nl3N2swaZ5Z8xBkLFpQ6E3JIjPPbnWWls4aH7fWSpONq2V'
    b'K761NEt2ignW339ArV7Xu61t79fLrT/s7WH8w4CI2p37R/2T1fEXJeb4wF5BsO0AAAAASUVO'
    b'RK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAFznpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHjarVdZduwoDP1nFb0ECxCC5TCe0zvo5fcVYKeml0ryYsdGBVhIuppi+n//'
    b'DvMPLsshGM8SQwrhwOWTTzaDiMe68nzT4ed7XnYv4ffdvLkWLKYcRrd+xrD3n/N0MVhDBsU3'
    b'jGLdC+V+IfnNPz4w2ic7lUjpthmlzcjZtUCbQV5qHSFFuVWh9DW2U5O4HqMvH+/FfvotsF5j'
    b'nOOs7Y7cgbd1dgng9CHjMgjC2zqsgOJJR7xBb2YwyCs7HTdSmUdULor+MP8Aigtr3mDi3pjh'
    b'Gl/OEz/Mb4ZmmvjmZFevk+/mq7u8687I+ozRohmjL+2yDzBp2EqdqkwKGwtM7uZnAbfgYdAy'
    b'74Q7GnhvBeTtqEfBXSmRBSyDPDXKNKjPsVKFiN52KxitrQBK56ITmyzENcDG603DikuuAS/r'
    b'KuB1mLWXLDTPTfO4ShEHN8JOS2BG6gpGX79x/5HRGOryREe8bAW5rDohxFDk9I1dAITG6Uc8'
    b'DXzej5fi6oAgTzNHKJiPslgUpu1b6kduAu2wkTGuWCNpmwFMhLMZwpADAkeAw1OgQ6wVItgx'
    b'Ap8MRtE6bwsgIGbbIKX1zgWAE62ejW+E5l7Ldk0jZwEIdsEJoEkuAyuPxAb/ER/hQ5kde2YO'
    b'LBw5cQ4u+IDsFyRo8svixAtLEJEoSXJ00UeOIUqMJqaYk00OyZFTSJJiSilnHJrBOePrjA05'
    b'F1tc8YVLKFJiSSVXuE/1lWuoUqOpqeZmm2vIEy00abGlljt1uFL3nXvo0mNPPQ+42nDDDx5h'
    b'yIgjjXyhRmbB+nR/HTU6UbMTKd0oF2r4VORkQZpOWDEDYtYTEBdFAA5tFbMjkvfWKHSK2ZGQ'
    b'2RxbSMkKTiNFDAj6TpYHXdh9IHeHm/H+r3CzJ3JGofsN5IxC9wfknnF7gVrTalMPZyZCGoZq'
    b'1MMh/LAp24g/1KSvj+a7H3yT0YiHLX2MTX6Bl3mzwYHbl+QyX5RnFAmlW7sIztx8DxVes74q'
    b'wbgU5/dZ+4XPxxFjnmT3rlllPnoBvDqfTWfq7FwWdqkPlA0ZjTyjDoaoo2dtLN6MPJBqWZoq'
    b'wfrMudCbVPi3EgH+l1NtMfbNFjkDuXTSx+1oHid0RDWjSXKNkr20UiYT4dRD0sV9eN1n1gFj'
    b'D5saLIcwasO7ZWK1Skbtems97ZaWrUyfnSJm2rLaJBoCDjYrRCezFnv4FH9z5zOAd4KZjuGj'
    b'Ah3zggrxl0ei2gbLcE4Ps2VtH3AL1GmjC1u6S0yLqP+GVlMp8zWtKGzSP7tA8oDCm8JIfWkh'
    b'GxT9iYnC5H12tcIBAARypF+az9OQqRrSVsrSgqtRpTDxw/tT8oKmMySAKAWOw+qdUo9FeHSS'
    b'Lxxoj2YT13Yl5gSkOsVrXBqIcueZwlTzqaBUg+w+p1OVHB4NsHS8/Fw8EnitQuyz1BTahqSg'
    b'HzY3Ib/NPQnKpR09VTf4a5iaz0H9FFPUCTwlo2yiYR90rGiv9ims4ssY/AhrhNgVYWaHmGKq'
    b'Pp2PTsdP1DXf9+HX6ppX+n5H3XM0z771gbYSsXGPggZg5DjT0MyAOx8lana7ivk0fx4fn75J'
    b'nsVozHFDR5o0ZFZsdkJyvwGgDvfWkubGpGexUaKGDDCzHIix29KkZK7oBB6zm/nbqsazYenJ'
    b'RELw1DPijtQTqQUmaC1Iyi9st0qDuJo18oA9Is8kaX4lVTWOtk0/U9Y8a/szZc29trbAZer0'
    b'yTOqbAs+xzZyaogNxBbZsySknfg175tXFeGqFLva58C2B8dZ/Eh2eeb0dobCsJSg8zTwqRHO'
    b'PK8Z6ocJyvxKxCJgzUMtnYZCdQjHbdEoxwhoSqHZVTVW0YirnERp5lwoOyJKrCgltWfWUnK2'
    b'NpzSm+g2z+G9W5wZrjfh/Sa6ze90R1rXjk+q3jcylHlOUd/IUDcbzJd6xPcniLkp7n/F0dCv'
    b'iPTISPDfTkLa/B88tfbyQcfN4QAAAYVpQ0NQSUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU6Ui'
    b'FQcrSnHIUJ0siBVx1CoUoUKoFVp1MHnpHzRpSFJcHAXXgoM/i1UHF2ddHVwFQfAHxM3NSdFF'
    b'SryvKbSI8cLjfZx3z+G9+wChXmaa1TUBaLptphJxMZNdFQOv8GEIgwgjJjPLmJOkJDzr6566'
    b'qe6iPMu778/qU3MWA3wi8SwzTJt4g3h60zY47xOHWFFWic+Jx026IPEj1xWX3zgXmizwzJCZ'
    b'Ts0Th4jFQgcrHcyKpkY8RRxRNZ3yhYzLKuctzlq5ylr35C8M5vSVZa7TGkECi1iCBBEKqiih'
    b'DBtR2nVSLKToPO7hDzf9ErkUcpXAyLGACjTITT/4H/yerZWPTbpJwTjQ/eI4H6NAYBdo1Bzn'
    b'+9hxGieA/xm40tv+Sh2Y+SS91tYiR0D/NnBx3daUPeByBxh+MmRTbkp+WkI+D7yf0TdlgYFb'
    b'oHfNnVvrHKcPQJpmlbwBDg6BsQJlr3u8u6dzbv/2tOb3A51ScriOJyF4AAAPoGlUWHRYTUw6'
    b'Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhp'
    b'SHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIg'
    b'eDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRl'
    b'c2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMu'
    b'b3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRw'
    b'Oi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9u'
    b'cy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBs'
    b'dXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1Q'
    b'PSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwu'
    b'b3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUu'
    b'Y29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAv'
    b'MS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOjBlZWQzMWFhLTc1'
    b'NDYtNGM2ZC05NDQxLTllZTRkYWE3ZDE3OSIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlp'
    b'ZDozNTk1MjA4Ni1jN2JkLTRiOWEtYmY3My1jZjA2YjhlZGMwODEiCiAgIHhtcE1NOk9yaWdp'
    b'bmFsRG9jdW1lbnRJRD0ieG1wLmRpZDozNDRhNmQ2My03NDJlLTQ5NWItYmZiZS00OTFiY2Q5'
    b'MmJiZGMiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAg'
    b'R0lNUDpUaW1lU3RhbXA9IjE2MTE0MzcyOTczODc0MTAiCiAgIEdJTVA6VmVyc2lvbj0iMi4x'
    b'MC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEi'
    b'CiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25D'
    b'cmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgog'
    b'ICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6'
    b'TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpC'
    b'YWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3Ry'
    b'eUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1N'
    b'Okhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlv'
    b'bj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNl'
    b'SUQ9InhtcC5paWQ6ZTBhODE0NDEtMTc1Yy00ZmM3LTgwNmMtOGFjM2ZhOWJkZTJiIgogICAg'
    b'ICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0'
    b'OndoZW49IjIwMjEtMDEtMjNUMTU6Mjg6MTctMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAg'
    b'PC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEv'
    b'PgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAg'
    b'PHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRP'
    b'd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1'
    b'czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRm'
    b'OkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+'
    b'eAgi0AAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UB'
    b'FxUcEezZejMAAAC6SURBVFjD7VdJDoAgDKzEK9z5DU/3N97lAXgR4xKwxRZMpAkXD53pTJcI'
    b'8PcYEt+DYO5TqE8rMM0LOaGzhqSCmAIb+dDUAgwJ8R54IlGlCXMkRinQSzNyWKAz71YtOpgU'
    b'0ADgkyRyaoy45MdkQ85ncigKOIfnRAX8TiRWnqrUWQPOGrISinnUuC2QJ9H8GnYCrARKRlG1'
    b'BGcjEMFLpgB5C/yWXNdexbJLqOAa+ldgfQ/U/jNC4TVXoMcKbII8fN8MSdgAAAAASUVORK5C'
    b'YII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADGHpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7ZZbkuMgDEX/WcUswZIQEsvBPKpmB7P8uWDH00l3V/Wr5ism5iHji9BR'
    b'SEL/83uEX7h4cw5RzVNOacMVc8xc0PHtuMqqaYurXhefjzC+s4frAcMkaOUYejrn3+x0CRxN'
    b'QU9fCHk9H+z3D3I89f1B6FxZpkez306hfAoJHw/oFCjHtraU3V5uYe9H22478eMOs4p+7/ar'
    b'sSF6TbGOMHch2VCz8OGAzJuCFHQINYvwYS4YO+oodoohIG/FaXvhVXikcvXoHfsDFEmHPcBw'
    b'H8x0tW/aSR/sp2BYIX6xstRr5Tt7/7fEXZDnPUbzMEY/dldiQkjTuanbVlYPE3eEXNZrCcVw'
    b'K/q2SkbxgOytQN62uu0olTIxsAyK1KjQoL7aShUuRu5saJkrQE2bi3HmKlsAoTgLDTbJ0sCL'
    b'pQKvwMqXL7TWzWu5So6FG2EmE8RopkKY1U+Ud4XGmClPtPkVK/jFMwnhxiQ3a8wCEBq3PNIV'
    b'4Ft5vCZXAUFdYXZssGz7IbErnbk180gWaMFERXt818jaKYAQYW2FMyQgsCUSpUSbMRsR4ujg'
    b'UyDkLJF3ICBVbvCSo0gCHOe5Nt4xWnNZ+TDjzAIIlSQGNFkKWEUcbMgfi44cKioaVTWpqWvW'
    b'kiTFpCklS/PwKyYWTS2ZmVu24uLR1ZObe/DsJXMWHI6aU7bsOedSsGiBcsHbBRNK2XmXPe66'
    b'p9123/NeKtKnxqo1Vaseaq6lcZOGc6KlZs1bbqVTRyr12LWnbt177mUg1YaMOHSkYcNHHuWi'
    b'RuHA+qp8nBrdqPEiNSfaRQ2vmt0kaB4nOpmBGEcCcZsEkNA8mW1OMXKY6CazLeNkE2V4qRNO'
    b'o0kMBGMn1kEXu3/k7riFGL/FjW/kwkT3E+TCRPcOudfc3qDW5q9N3SQsQvNrOIO6Cb5+mFTY'
    b'8cFv0sfb8NkXnkJPoafQR9r5D3B2pY+xRuF++PVR+BkZbO3LMmt/Y9wehUfDV8fhuwL/y6PP'
    b'J0T4fio+hZ5CT6FXrQz8M8rhLyR56srbTAdGAAABhGlDQ1BJQ0MgcHJvZmlsZQAAeJx9kT1I'
    b'w1AUhU9TRZGKiB2KOGSoTlZERRy1CkWoEGqFVh1MXvoHTRqSFBdHwbXg4M9i1cHFWVcHV0EQ'
    b'/AFxc3NSdJES70sKLWK88Hgf591zeO8+QKiXmWZ1jAOabpupRFzMZFfFrlcEEIGAfozJzDLm'
    b'JCkJ3/q6p26quxjP8u/7s3rVnMWAgEg8ywzTJt4gnt60Dc77xGFWlFXic+JRky5I/Mh1xeM3'
    b'zgWXBZ4ZNtOpeeIwsVhoY6WNWdHUiKeIo6qmU76Q8VjlvMVZK1dZ8578haGcvrLMdVpDSGAR'
    b'S5AgQkEVJZRhI0a7ToqFFJ3HffyDrl8il0KuEhg5FlCBBtn1g//B79la+ckJLykUBzpfHOdj'
    b'GOjaBRo1x/k+dpzGCRB8Bq70lr9SB2Y+Sa+1tOgR0LcNXFy3NGUPuNwBIk+GbMquFKQl5PPA'
    b'+xl9UxYYuAV61ry5Nc9x+gCkaVbJG+DgEBgpUPa6z7u72+f2b09zfj9NWnKYMAC+RAAAD6Bp'
    b'VFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVN'
    b'ME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+Cjx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6'
    b'bWV0YS8iIHg6eG1wdGs9IlhNUCBDb3JlIDQuNC4wLUV4aXYyIj4KIDxyZGY6UkRGIHhtbG5z'
    b'OnJkZj0iaHR0cDovL3d3dy53My5vcmcvMTk5OS8wMi8yMi1yZGYtc3ludGF4LW5zIyI+CiAg'
    b'PHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIKICAgIHhtbG5zOmlwdGNFeHQ9Imh0dHA6'
    b'Ly9pcHRjLm9yZy9zdGQvSXB0YzR4bXBFeHQvMjAwOC0wMi0yOS8iCiAgICB4bWxuczp4bXBN'
    b'TT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIKICAgIHhtbG5zOnN0RXZ0PSJo'
    b'dHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvc1R5cGUvUmVzb3VyY2VFdmVudCMiCiAgICB4'
    b'bWxuczpwbHVzPSJodHRwOi8vbnMudXNlcGx1cy5vcmcvbGRmL3htcC8xLjAvIgogICAgeG1s'
    b'bnM6R0lNUD0iaHR0cDovL3d3dy5naW1wLm9yZy94bXAvIgogICAgeG1sbnM6ZGM9Imh0dHA6'
    b'Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICAgeG1sbnM6dGlmZj0iaHR0cDovL25z'
    b'LmFkb2JlLmNvbS90aWZmLzEuMC8iCiAgICB4bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5j'
    b'b20veGFwLzEuMC8iCiAgIHhtcE1NOkRvY3VtZW50SUQ9ImdpbXA6ZG9jaWQ6Z2ltcDoxMDc2'
    b'ODViYy04YmI5LTRmZDktOGQ3YS03NmZhYjUwMTBhM2QiCiAgIHhtcE1NOkluc3RhbmNlSUQ9'
    b'InhtcC5paWQ6YzRhYmMxOGItMTk2Yy00YzFkLWI0OTktZWRhY2U5MmM3ZjhhIgogICB4bXBN'
    b'TTpPcmlnaW5hbERvY3VtZW50SUQ9InhtcC5kaWQ6NmQ3MGYzZjktMTJkMi00ZjBlLTg1Yzgt'
    b'ZTY4YzAxMjI1Y2I0IgogICBHSU1QOkFQST0iMi4wIgogICBHSU1QOlBsYXRmb3JtPSJNYWMg'
    b'T1MiCiAgIEdJTVA6VGltZVN0YW1wPSIxNjExNDU0NzI5NjcwNDgzIgogICBHSU1QOlZlcnNp'
    b'b249IjIuMTAuMjIiCiAgIGRjOkZvcm1hdD0iaW1hZ2UvcG5nIgogICB0aWZmOk9yaWVudGF0'
    b'aW9uPSIxIgogICB4bXA6Q3JlYXRvclRvb2w9IkdJTVAgMi4xMCI+CiAgIDxpcHRjRXh0Okxv'
    b'Y2F0aW9uQ3JlYXRlZD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkxvY2F0aW9uQ3Jl'
    b'YXRlZD4KICAgPGlwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgIDxyZGY6QmFnLz4KICAgPC9p'
    b'cHRjRXh0OkxvY2F0aW9uU2hvd24+CiAgIDxpcHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAg'
    b'IDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAgPGlwdGNFeHQ6'
    b'UmVnaXN0cnlJZD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OlJlZ2lzdHJ5SWQ+CiAg'
    b'IDx4bXBNTTpIaXN0b3J5PgogICAgPHJkZjpTZXE+CiAgICAgPHJkZjpsaQogICAgICBzdEV2'
    b'dDphY3Rpb249InNhdmVkIgogICAgICBzdEV2dDpjaGFuZ2VkPSIvIgogICAgICBzdEV2dDpp'
    b'bnN0YW5jZUlEPSJ4bXAuaWlkOjJiODMwOGNlLTIyMWUtNDk0My1hNzY0LTQ5NjczNGFmNzM5'
    b'MiIKICAgICAgc3RFdnQ6c29mdHdhcmVBZ2VudD0iR2ltcCAyLjEwIChNYWMgT1MpIgogICAg'
    b'ICBzdEV2dDp3aGVuPSIyMDIxLTAxLTIzVDIwOjE4OjQ5LTA2OjAwIi8+CiAgICA8L3JkZjpT'
    b'ZXE+CiAgIDwveG1wTU06SGlzdG9yeT4KICAgPHBsdXM6SW1hZ2VTdXBwbGllcj4KICAgIDxy'
    b'ZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlU3VwcGxpZXI+CiAgIDxwbHVzOkltYWdlQ3JlYXRv'
    b'cj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlQ3JlYXRvcj4KICAgPHBsdXM6Q29w'
    b'eXJpZ2h0T3duZXI+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpDb3B5cmlnaHRPd25lcj4K'
    b'ICAgPHBsdXM6TGljZW5zb3I+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpMaWNlbnNvcj4K'
    b'ICA8L3JkZjpEZXNjcmlwdGlvbj4KIDwvcmRmOlJERj4KPC94OnhtcG1ldGE+CiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAKPD94cGFja2V0IGVu'
    b'ZD0idyI/Pk+nw7YAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAH'
    b'dElNRQflARgCEjEIPtLWAAAAJklEQVRYw+3RQREAIAzAsIJ/z0PGHiQKetcCAJadajYDrgcA'
    b'8L0HrbwBA/7oszMAAAAASUVORK5CYII=')





from typing import Callable

from logging import Logger
from logging import getLogger

from wx.lib.sized_controls import SizedPanel

from hasiihelper.Position import Position

from hasiicommon.ui.widgets.DualSpinnerControl import DualSpinnerControl
from hasiicommon.ui.widgets.DualSpinnerControl import SpinnerValues


class PositionControl(DualSpinnerControl):
    """
    A facade around the basic dual spinner control;   Essentially
        * Converts the spinner values to and from the Position type;
        * Handles the spinner callback
        * Forwards the spinner values as Position values

    """
    POSITION_MIN_VALUE: int = 0     # For the control only
    POSITION_MAX_VALUE: int = 2048  # For the control only

    def __init__(self, sizedPanel: SizedPanel, displayText: str,
                 valueChangedCallback: Callable,
                 minValue: int = POSITION_MIN_VALUE, maxValue: int = POSITION_MAX_VALUE,
                 setControlsSize: bool = True):
        """

        Args:
            sizedPanel          The parent window
            displayText:        The text to display as the position  title
            valueChangedCallback:  The method to call when the value changes;  The method should expect the
                                    first parameter to be a Position argument that is the new value
            minValue:       The minimum position value
            maxValue:       The maximum position value
        """
        self.logger:                   Logger   = getLogger(__name__)
        self._positionChangedCallback: Callable = valueChangedCallback
        self._position:                Position = Position()

        super().__init__(sizedPanel, displayText, self._onSpinValueChangedCallback, minValue, maxValue, setControlsSize)

    def _setPosition(self, newValue: Position):
        self._position = newValue
        self.spinnerValues = SpinnerValues(value0=newValue.x, value1=newValue.y)

    position = property(fset=_setPosition, doc='Write only property to set values')

    def _onSpinValueChangedCallback(self, spinnerValues: SpinnerValues):
        self.logger.info(f'{spinnerValues}')
        self._position.x = spinnerValues.value0
        self._position.y = spinnerValues.value1

        self._positionChangedCallback(self._position)



#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AE1vIDE3IEZlYiAyMDAzIDIzOjQ5OjQ2ICswMTAwscrZowAAAAd0SU1FB9MCERcmCB53GVgA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAADBElEQVR42uVXS2sUQRCu'
    b'6VnjOWdB8ZA/4U+IRy+CwUSzzqIH2YDoKScFL0I8JThGEzTB10klexC8iOALwUMgGHPxoIuL'
    b'rksSEtfd2bJ7pmu2el4b93EQCybdWzPMV/V9VdUZgP/dLP5j7nVjRi5FRASQV7i2WhDzaX/o'
    b'A0i/x/yV1dXr16ZHp2KRKPDZV79xUNbwEN+vV3HheRkvXC7NEG6ONi3PK547sh+26gCfqgDf'
    b'd+RNyU9OANgiWP299Antt/TKfwu6IFh9mrXv0IFhCfgTyiMjRemeMgJAz/NXAh+KAKsX2Cwg'
    b'AuXAOb3yQADM/eGDw4DvKhBjwNcM2uAr990QyM9G/jl+0oFHd5lfg42fcmB50TXALMpeM5A/'
    b'40AUKypB4LCCDKPgttVmhGdps+cJLFz1XjCpOFaiBETrsTEnpJzXwZjM1t9bphSTecdgRkRk'
    b'4IZJAbQ0LQT0eNkNM6cXcVbGJwPaBWWpGVDPFwoOuK5rgDpOW4JkBnQARFUaOPmGbDNLm+ne'
    b'0fTcSJVAvUwVHLGxz9ZSWGZnqKxyIplqnnEMP6kIKQDSXVU7vVzRfU/THV6MIQUWpTwrCC6B'
    b'iEYlol0g2kMlCbwby25DDXxiIpCABtLpvBObinulPBZAVhHSeH1wxzX6nJgpSKDb827ii7kU'
    b'UVnSuiAmAR+vthWv9GjmvUoQ2pWlNf/U2viB+LmGWN5ErGwj1nYRt+uI9Sai1+rPyXjx6rOw'
    b'DxPbUGWrhgyn/qwcLvM304fL31iiBOS09Knm7wHak67Lik+UIKsISe8J2ftq2qkhpNZeMo4F'
    b'kDWI6KRbWnBD+jsVXlLFZ50FmDmIWBBWD8Mmy3gNhDY9+8av0G9biNUdxM1fiLuN/lU+t/OX'
    b'HqZ3AdniLdegP23ep9GcZdipC8QA6Y9KYDCgjmnqAvU/XHTm960L0orww0bNeHAQDKytV4w2'
    b'bEvQbJZevPwIX77WunrxXsGfPnmrJCiRz8hRzugVGcio8RmW8lmW9cmWeQ+gdGMuf3RgWf5z'
    b'9gcwQL7Lcp8odwAAAABJRU5ErkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAADUXpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7ZZtstsqDIb/s4ouAUkIxHIwmJm7gy6/L/5qnI/eJCedTmdqjgHLQhJ6'
    b'ZHLc/P2/7r7hYs/mgiaLOUaPK+SQuWBifr3K0pMPS789+H1ykrvjBUMkGGV9tLjp73LyJ0tU'
    b'MNMLQ1a3F9P5RQ6bfbsyxOsgI6Ixb5uhvBkSXl/QZqCs2/IxW7rcwjSvY9t3YuvtRhfsHPbN'
    b'c0L2msKPMM9C4tGz8BqAjJucFEwIPUniMRPMVWyR7MaQkHt58hdRuWsqx4weyK+gSFzlDoJz'
    b'MuMx3pWTXsk3g25J8YVnqYfnk7zkw8UpyePuvZnrfV53V0JESuO2qSM7YwLFCSmXZVlES7gV'
    b'87S0jGYO1VuBvPnqJ7RKmRhZ7hSoUaFO8zJWqggx8MxAwswVoIbMgChzFe/AJoxGnZNkaeDF'
    b'UoFXIOUjFlr85sVdJYPjRtBkgjEapeBG94n20FDvo+SJvB25Qlw8ihBhDHKjhxaAUN/rSJcE'
    b'7+36GlwFBHVJs2GDxU+riUlpq61RR7KAFigqxvVbo9Q2A0gRfCuCIQEBH0mUIvnEnIiQRwOf'
    b'AkPGEngCAlLlhig5iETAMR6+sSbRosvKqxhnFkCoRElAk6WAVcDBhvpJwVBDRUWDqkZNapq1'
    b'RIkhaowxxXH4lSQpJE0xpWQpp2JiwdSiJTNn2UrmLDgcNcecsuWcS4HTAssFqwsUSpl4kilM'
    b'OsUpTTblqVSUTw1Va6ypmqu5lsZNGs6JFltq1nIrM80opTnMOsc5zTbnuXSUWpceuvbYU7ee'
    b'ezmokVux3rTnqdFOjRdSQzEd1LA0pd0EjeNEBzMQ40AgngYBFDQPZt4oBHYD3WDmM+OrUEaU'
    b'OuA0GsRAMMzE2ulg95PciZsL4UvceCfnBrpPkHMD3QNyt9zuUGvj16Z6cQuh8RmOpHrB5wel'
    b'woY/HIvPj+7VBX+5IZlft+WOtb2/Gc/q1l3J3jbn7mzjCXO3q9xXoniY7Oeiu9C6eOs+gf6u'
    b'ofv+7kv/aEH+LxL3mXhOht6rKP9xau9S+ii1S3ful5X7QlTuC1Gc3LjX1N/M0Svm3FubuTO6'
    b'B2tfPqN+3zHyz9ATR23HvyoZv5w/APjexnblioeKAAABhmlDQ1BJQ0MgcHJvZmlsZQAAeJx9'
    b'kT1Iw1AUhU9TpSIVkXYQcchQnSyIioqTVqEIFUKt0KqDyUv/oElDkuLiKLgWHPxZrDq4OOvq'
    b'4CoIgj8gbm5Oii5S4n1JoUWsFx7v47x7Du/dBwi1EtOsjlFA020zGY+J6cyqGHiFD30IYQoz'
    b'MrOMOUlKoG193VM31V2UZ7Xv+7N61KzFAJ9IPMsM0ybeIJ7ctA3O+8RhVpBV4nPiEZMuSPzI'
    b'dcXjN855lwWeGTZTyXniMLGYb2GlhVnB1IgniCOqplO+kPZY5bzFWStVWOOe/IXBrL6yzHVa'
    b'g4hjEUuQIEJBBUWUYCNKu06KhSSdx9r4B1y/RC6FXEUwciygDA2y6wf/g9+ztXLjY15SMAZ0'
    b'vjjOxxAQ2AXqVcf5Pnac+gngfwau9Ka/XAOmP0mvNrXIEdC7DVxcNzVlD7jcAfqfDNmUXclP'
    b'S8jlgPcz+qYMELoFute8uTXOcfoApGhWiRvg4BAYzlP2ept3d7XO7d+exvx+AOMMctRM/HtO'
    b'AAAPoGlUWHRYTUw6Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlk'
    b'PSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9i'
    b'ZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYg'
    b'eG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMj'
    b'Ij4KICA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0i'
    b'aHR0cDovL2lwdGMub3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5z'
    b'OnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RF'
    b'dnQ9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIK'
    b'ICAgIHhtbG5zOnBsdXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAg'
    b'ICB4bWxuczpHSU1QPSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0i'
    b'aHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRw'
    b'Oi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFk'
    b'b2JlLmNvbS94YXAvMS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1w'
    b'OmNlZTBmODhhLTE3NWUtNDY3MC04YzU5LWIzMDIzOTMyMjUxNCIKICAgeG1wTU06SW5zdGFu'
    b'Y2VJRD0ieG1wLmlpZDpmMTRkNjAyYi1mMTlmLTQ3MTktYjE3NC01ZWNjOTQ3YTYxNjAiCiAg'
    b'IHhtcE1NOk9yaWdpbmFsRG9jdW1lbnRJRD0ieG1wLmRpZDpjMzFkOGE4NS0yMjY3LTQ5ODEt'
    b'YWE3OC02YWFlYmM1MzhiNDAiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09'
    b'Ik1hYyBPUyIKICAgR0lNUDpUaW1lU3RhbXA9IjE2MTA5MTM0OTMyMjQxODIiCiAgIEdJTVA6'
    b'VmVyc2lvbj0iMi4xMC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3Jp'
    b'ZW50YXRpb249IjEiCiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNF'
    b'eHQ6TG9jYXRpb25DcmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRp'
    b'b25DcmVhdGVkPgogICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgog'
    b'ICA8L2lwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0'
    b'PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0'
    b'Y0V4dDpSZWdpc3RyeUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJ'
    b'ZD4KICAgPHhtcE1NOkhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAg'
    b'IHN0RXZ0OmFjdGlvbj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0'
    b'RXZ0Omluc3RhbmNlSUQ9InhtcC5paWQ6ZjllNjVlN2UtNTNjOS00MmVkLThiZTMtN2JmNTZi'
    b'Y2Y4NTU4IgogICAgICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUyki'
    b'CiAgICAgIHN0RXZ0OndoZW49IjIwMjEtMDEtMTdUMTM6NTg6MTMtMDY6MDAiLz4KICAgIDwv'
    b'cmRmOlNlcT4KICAgPC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgog'
    b'ICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VD'
    b'cmVhdG9yPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1'
    b'czpDb3B5cmlnaHRPd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93'
    b'bmVyPgogICA8cGx1czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vu'
    b'c29yPgogIDwvcmRmOkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAK'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNr'
    b'ZXQgZW5kPSJ3Ij8+5VxkAAAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqc'
    b'GAAAAAd0SU1FB+UBERM6DRrghjYAAAA/SURBVDjLY2AYaMCIRew/iepRNP4nYCFONcRoxqv+'
    b'Pxne/0+JZrheJkpjgYla0Ul2GDCRach/qqUDqqbEIQoAd9MV9YEt+iEAAAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAGrXpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHjarVdZlisrDvxnFb0EJiGxHMZzege9/A4B6Zt2Ta73rrOcqEhSIEVosBn/'
    b'++80/8HHp5xMJBaMyeITc8y+QBC7P2XdnY3rvj7+PML/T/Pm8cBjKmAM+19JZ/017x4K9lAg'
    b'0U2RtPOgPj/I8eiXF0Vn56AnUrkfRfkoCn4/cEdB2WbZlIXvJtSxx35ZIvtr9Bbl+dgf/md4'
    b'rxP2Cd6P4ILF3Qe/DxD060woEBzuPuAJpLRkj7sLl6lwyGd+srdTmVdUHpL7Yv4FlJD2vMHE'
    b'szPTY/x03tHL/FFolotvO4f22PlpPpLNr+Zc3zm7mDnHtq7EBJemY9RlypKwsEJVWK8lXIwv'
    b'QeZ1ZVxiwN4GyLtttuJqLjsPWKaLrrviphtrbK7hiNEPzxi9bwBK5ySwz74Fa4BN1MtNzyGH'
    b'HgSINcAbMOsfZ3Fr37y2a06wcXdY6R2UOUXZLKj/wvWlojmV8s5ZefgK5/JKQhxDkdM7VgEQ'
    b'Ny8e0XLwdb1+FNcABGm5WWBgsXWrqOQOt5RHYQEdsJAw7lhz3I8CuAh7Ew7jAhCwCYR3yVn2'
    b'np2DHwX4FCgSH6KvgMAR+Y5T+hhCAjjidW+8w26t9eT3NHIWgCAEEwOaHAqwikhs4A9HAYcK'
    b'BYpElIhJKFNJIcVEKSVOmvwKB45MnJhZOHORIFFIkrCIkSwl+xyQHCmnzFlyzqVg0wLNBW8X'
    b'LCil+hpqrFRT5So119JAnxYbtdS4iWm5le576MgTPXXu0nMvww1QacRBIw0eMvIoE1SbYcZJ'
    b'M02eMvMsD9Sc2bB+uN5HzV2o+YWULuQHaniV+VLhNJ2QYgbEfHRAnBUBENorZlZcjN4odIqZ'
    b'zchsgTxOSQpOd4oYEIzDeZrugd0f5J5wMzH+K9z8hZxR6P4Gckah+wK5j7h9glrXatNsMAsh'
    b'DUN1qg0IPywqXvCHmvT+aH77wi8VTbG+jjmP+IYu88OCAG1vncu8eZ5ZOdXh/RaoUI8jNbBm'
    b'v1WTCVnW+0X7he/HKVKWOGLoXpXPUQGvzhczyA0KoTCFPCbKBs/uIqEOJtER9cz+ONJEqiXu'
    b'agTpd82l0bmB3yok8K/k1kXGUYucgVy6ZHsfzeuEjqhmbonUhEvkXutSwpRHyvrwbN7Onm3C'
    b'2dPnDs8hjPqMYbtYvVJQu370nnZL21dmrE4RM317bQkdAQefVecuZV1G+hZ/88QZwLvAzHZG'
    b'UaClbKgQf2Vm1/okniHoZr7u5RO0QJ02+uCc7nFMdFnxF1Yto8x7Vrl0xPiRAjkCimgqIfXl'
    b'jWxS9BcmClOMJbQGAgAI5Mi4LV+7IVN1pK1cuKfQRE9h5A/7c46MpjNlgMgVxCFlJze7hYhO'
    b'8hMCndEc4bFchTWBU13H61Q7hPrETCbXilpgNRLYOIqg7mA4pnDL3I+bW+vx5tg+1I1pCUNa'
    b'mA8/IkfDgd30go2a30TO8uewjzBZgnQawqgos8g9qFSk7Lo37wTkO/Fottle54NmdVoCL18I'
    b'D/XCNanCnjuegh1U0TDCom6UB3DbsCiJd5G0Trrjr5huBzz8WELCnsWh8WSz9ryjvIrl1zB/'
    b'hbK5w4wU2r3mgYQgsXVBq+gDXfAToI5EN3o6pSDiAYKvJhflXwyopxTAQ5TVxWv1ZaSwQjLx'
    b'a6wqiQt+IY2E5JrjzB7wbzsQIIijqpFDrD8cBcUaFEulHQT9qgUnJJfgSu12ZGUVytG/D/xF'
    b'WPNF4FNZlAVBghLW3fwV+3ZXfnKX2fT31c9SJ+J5XvGc5I8v21AHole6is1zLCJBZIMnYRc6'
    b'Wj3MyOJwgkUptMu9HYvi1xRaDDJ/gUJLt/mUQjiK31FbtKyJ0idPDfnth4tDOL/mLgsGGFBg'
    b'MwC2gEchuFSfuNZYnX9AfuoBSibNUrL2NivjOuo2k+bmKxndsb5aBxVaKoCpsEXGvDcaqGto'
    b'Wxoau5+bqe97FPPapBxWjZKQaAhVuLUdREji8BqvZBL09VAkTq0BvXWeRvoAkreKV1YttNxp'
    b'tnaLSlUOMgeGD8IU+JMfgauNFs7DCDrbSiEtHtrMrOqUa835kEF+dpk5Prt74HcuOw4z33R1'
    b'Wl4jjCqMMgNAl18W7JWyBhyfmEF4OSVkX9lciwgj5PCDBDhy1iZph2lH5CCgteNDFdVga0pY'
    b'GE0BysLpRvKnUfCrUqSvmb9RirQSmafesO4Sw89FZS/4Lo4xmn9qyqsF5idT3u2Qzfut9D1z'
    b'fVxg3t7yh/EfK+KJH32gjvk/m2s+2XguEicAAAGFaUNDUElDQyBwcm9maWxlAAB4nH2RO0jD'
    b'UBSG/7ZKRSoO1icOGaqTBVERR61CESqEWqFVB5ObvqBJQ5Li4ii4Fhx8LFYdXJx1dXAVBMEH'
    b'iJubk6KLlHhuUmgR44HL/fjv+X/uPRfw10pMNdvGAVWzjGQ8JqQzq0LwFT70ow+9GJSYqc+J'
    b'YgKe9XVP3VR3UZ7l3fdndSlZkwE+gXiW6YZFvEE8vWnpnPeJw6wgKcTnxGMGXZD4keuyy2+c'
    b'8w77eWbYSCXnicPEQr6F5RZmBUMlniKOKKpG+f60ywrnLc5qqcIa9+QvDGW1lWWu0xpGHItY'
    b'gggBMiooogQLUdo1Ukwk6Tzm4R9y/CK5ZHIVwcixgDJUSI4f/A9+z9bMTU64SaEY0P5i2x8j'
    b'QHAXqFdt+/vYtusnQOAZuNKa/nINmPkkvdrUIkdA9zZwcd3U5D3gcgcYeNIlQ3KkAC1/Lge8'
    b'n9E3ZYCeW6BzzZ1b4xynD0CKZpW4AQ4OgdE8Za97vLujdW7/9jTm9wNSpnKaj6yxkQAAD6Bp'
    b'VFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVN'
    b'ME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+Cjx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6'
    b'bWV0YS8iIHg6eG1wdGs9IlhNUCBDb3JlIDQuNC4wLUV4aXYyIj4KIDxyZGY6UkRGIHhtbG5z'
    b'OnJkZj0iaHR0cDovL3d3dy53My5vcmcvMTk5OS8wMi8yMi1yZGYtc3ludGF4LW5zIyI+CiAg'
    b'PHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIKICAgIHhtbG5zOmlwdGNFeHQ9Imh0dHA6'
    b'Ly9pcHRjLm9yZy9zdGQvSXB0YzR4bXBFeHQvMjAwOC0wMi0yOS8iCiAgICB4bWxuczp4bXBN'
    b'TT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIKICAgIHhtbG5zOnN0RXZ0PSJo'
    b'dHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvc1R5cGUvUmVzb3VyY2VFdmVudCMiCiAgICB4'
    b'bWxuczpwbHVzPSJodHRwOi8vbnMudXNlcGx1cy5vcmcvbGRmL3htcC8xLjAvIgogICAgeG1s'
    b'bnM6R0lNUD0iaHR0cDovL3d3dy5naW1wLm9yZy94bXAvIgogICAgeG1sbnM6ZGM9Imh0dHA6'
    b'Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICAgeG1sbnM6dGlmZj0iaHR0cDovL25z'
    b'LmFkb2JlLmNvbS90aWZmLzEuMC8iCiAgICB4bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5j'
    b'b20veGFwLzEuMC8iCiAgIHhtcE1NOkRvY3VtZW50SUQ9ImdpbXA6ZG9jaWQ6Z2ltcDphOGU1'
    b'YmY1NS03OGU4LTQ2N2MtOTJmZS03ZTEwZGY0MDBlMDIiCiAgIHhtcE1NOkluc3RhbmNlSUQ9'
    b'InhtcC5paWQ6MmIwYzM0ZDMtZGIxMi00YjkyLWIxNWUtNWQ5NGM5MTA5NWY1IgogICB4bXBN'
    b'TTpPcmlnaW5hbERvY3VtZW50SUQ9InhtcC5kaWQ6ZmViYjI1YTktODc5NC00ZDlmLTg5Njgt'
    b'YjZhYzk5M2JhY2JlIgogICBHSU1QOkFQST0iMi4wIgogICBHSU1QOlBsYXRmb3JtPSJNYWMg'
    b'T1MiCiAgIEdJTVA6VGltZVN0YW1wPSIxNjExNDQwNTM3Nzk2NTYyIgogICBHSU1QOlZlcnNp'
    b'b249IjIuMTAuMjIiCiAgIGRjOkZvcm1hdD0iaW1hZ2UvcG5nIgogICB0aWZmOk9yaWVudGF0'
    b'aW9uPSIxIgogICB4bXA6Q3JlYXRvclRvb2w9IkdJTVAgMi4xMCI+CiAgIDxpcHRjRXh0Okxv'
    b'Y2F0aW9uQ3JlYXRlZD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkxvY2F0aW9uQ3Jl'
    b'YXRlZD4KICAgPGlwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgIDxyZGY6QmFnLz4KICAgPC9p'
    b'cHRjRXh0OkxvY2F0aW9uU2hvd24+CiAgIDxpcHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAg'
    b'IDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAgPGlwdGNFeHQ6'
    b'UmVnaXN0cnlJZD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OlJlZ2lzdHJ5SWQ+CiAg'
    b'IDx4bXBNTTpIaXN0b3J5PgogICAgPHJkZjpTZXE+CiAgICAgPHJkZjpsaQogICAgICBzdEV2'
    b'dDphY3Rpb249InNhdmVkIgogICAgICBzdEV2dDpjaGFuZ2VkPSIvIgogICAgICBzdEV2dDpp'
    b'bnN0YW5jZUlEPSJ4bXAuaWlkOjkyYmI0OWEwLWFlZWEtNGEzMy05MzllLWEzYWUxNjM5YjZk'
    b'YiIKICAgICAgc3RFdnQ6c29mdHdhcmVBZ2VudD0iR2ltcCAyLjEwIChNYWMgT1MpIgogICAg'
    b'ICBzdEV2dDp3aGVuPSIyMDIxLTAxLTIzVDE2OjIyOjE3LTA2OjAwIi8+CiAgICA8L3JkZjpT'
    b'ZXE+CiAgIDwveG1wTU06SGlzdG9yeT4KICAgPHBsdXM6SW1hZ2VTdXBwbGllcj4KICAgIDxy'
    b'ZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlU3VwcGxpZXI+CiAgIDxwbHVzOkltYWdlQ3JlYXRv'
    b'cj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlQ3JlYXRvcj4KICAgPHBsdXM6Q29w'
    b'eXJpZ2h0T3duZXI+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpDb3B5cmlnaHRPd25lcj4K'
    b'ICAgPHBsdXM6TGljZW5zb3I+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpMaWNlbnNvcj4K'
    b'ICA8L3JkZjpEZXNjcmlwdGlvbj4KIDwvcmRmOlJERj4KPC94OnhtcG1ldGE+CiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAKPD94cGFja2V0IGVu'
    b'ZD0idyI/Ps/VMmAAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAH'
    b'dElNRQflARcWFhEUcCzgAAAA6UlEQVRYw+1XSw6EIAwtxi3uuQ1H5zTj3h6AWTiaIJ8p2ILJ'
    b'TBM3xrSv79NEgF8vlXnvBXsHNT2aAbdu1Q2tWapYEGPgA94PlYACQtwD30B0MWEJxCw19GJG'
    b'Dgl04Ym2JRcTAxoAMAuixMZMa340UhmNfQSCWtPd4bnvmSRAANDn8H1T3mrwALJtz3wHUI4B'
    b't3qwRkU+SEeuzoxkBlL6W7OQD84NBvDU9woinQwc5QHBFIQxxITrdTMAZgZQggEN7rUlNQ89'
    b'gYIMKC1yAypSsIM4mOAY3HaKAyawXwo4B/b8MyLNG36I/vUGQnpI8C4+/nkAAAAASUVORK5C'
    b'YII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADbnpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7ZZbdtwgDIbfWUWXYEkIxHIwmHO6gy6/P2C745lJO0nT05eYmIsASeiT'
    b'mbjtx/fmvuFhWsx5jRZSCAsen3zijI4t88mjpsWPejy8T2F8kbtzgiEStDKHFvb1h5xOBbPJ'
    b'6OmNIiv7xHqdSH7Xb3eKdsvSPer9uitKuyLhOUG7gjyPtYRk8fYI6zbbepzE5ut65e3q9sM4'
    b'InpVYUeYNyFZULPwdED6S04yOoSaBTPoJfQVoyxeDk8QkGdxWm68cvdUzh69Ib+DImHKHQTX'
    b'YIazfSonvZPvCt0I8Y1lKafli7zl08QlyP1trZprbZunyz4gpGE/1HGU0cPCFSGXsS2gRLyK'
    b'fhwloZhD9hYgr0tZVpRCiRhYGnmqlKnRNtpCBS563jiiZS4A1WUmkRMXWRw4+V6ocQSxKgZi'
    b'BXgFUj59oWE3DXOFDIYrYSUTlFFPBderzyhvKmqtpzzhuz5jBb+4JyHc6OR6jVUAQu3IIx0B'
    b'Psr907kKCOoIs+GAeVmnilVpz62eRzJACxYq2vmtUay7AoQIthXOkIDAEkiUAi2RORIhjgY+'
    b'GYqMxfMKBKTKFV6yFwmAY9xtY0+ksZaVpxh3FkCoBIlAg08KrDwuNuRP9IYcyirqVTVoVNOk'
    b'OUjwQUMIMfTLL0eJPmoMMUaLKWYT86YWLJo5S5YTJ8HlqCmkmCyllDOMZmjO2J2xIOeVV1n9'
    b'qmtY42prWnNB+hRftIQSi7mSSq5cpeKeqKHGajXVvNGGVNr8plvY4mZb2nJDqjVpvmkLLTZr'
    b'qeWTGrmJ9aG8To0OajxI9YXxpIatMR4qqF8n2pmBGHsC8dgJIKG5M1uMvGfX0XVmS8LNJsrw'
    b'UjucSp0YCPqNWBud7H6Ru3Bz3v8VNz7IuY7uM8i5ju4Nco/cnlCr/demLOIGof4Z9qAugs8P'
    b'izIb/vCb9Hrr3rvhS9GXov+mSPBrntvatv7f1RQ0ZP16iG93uL/35SVFV5+mF0MGt1o73OxT'
    b'7hXHxXKXi85V5dnI/W7yPSP3ro0Px3yI0fNz97W52TKDtg6dfa5rvR+5302+Z+Q+sPHp8dwF'
    b'+YXfONNDLD6YR6/nl7t4MtbdpN0MN/9Djy6eDePuI9afte5zLpEvRV+K/pi9Df9OJfcTJj8D'
    b'ywWmHkEAAAGEaUNDUElDQyBwcm9maWxlAAB4nH2RO0jDUBSG/6ZKRSoOZijikKE6WRAr4qhV'
    b'KEKFUCu06mBy0xc0aUhSXBwF14KDj8Wqg4uzrg6ugiD4AHFzc1J0kRLPTQotYj1wuB//Pf/h'
    b'3HMBoVFhut0zAeiGY6WTCSmbW5VCrwggQhmHqDDbnJPlFLrG1z1VUtzFeK/udX/GgJa3GRCQ'
    b'iGeZaTnEG8TTm47JeZ9YZCVFIz4nHrdoQOJHrqs+v3EueizwnqKVSc8Ti8RSsYPVDmYlSyee'
    b'Io5qukH9hazPGuctznqlxlpz8heG88bKMtcpR5DEIpYgQ4KKGsqowEGMToMUG2m6T3TxD3t+'
    b'mVwqucpg5FhAFToUzw/+B793axfik36ncALofXHdj1EgtAs06677fey6zRMg+AxcGW1/tQHM'
    b'fJJeb2vRI2BwG7i4bmvqHnC5A0SeTMVSPClIKRQKwPsZfVMOGLoF+tf8vbXucfoAZGhXqRvg'
    b'4BAYK1Lv9S7v7uvc2781rf39AF8Fcp9XazAmAAAPoGlUWHRYTUw6Y29tLmFkb2JlLnhtcAAA'
    b'AAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQi'
    b'Pz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENv'
    b'cmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRlc2NyaXB0aW9uIHJkZjph'
    b'Ym91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMub3JnL3N0ZC9JcHRjNHht'
    b'cEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29t'
    b'L3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFw'
    b'LzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBsdXM9Imh0dHA6Ly9ucy51'
    b'c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1QPSJodHRwOi8vd3d3Lmdp'
    b'bXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRz'
    b'LzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyIK'
    b'ICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wLyIKICAgeG1wTU06'
    b'RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOjk2N2I0NjYzLWM0YzgtNDQ0OS1iYzRkLWQ2'
    b'MjY5MzBhY2E4ZCIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDplNjYxYTIxYi1kMDc3'
    b'LTQzODctYTkwYS0wOWU0Yjk5ZDBkYTQiCiAgIHhtcE1NOk9yaWdpbmFsRG9jdW1lbnRJRD0i'
    b'eG1wLmRpZDozYThjMWFmNS01YmFlLTQ1MWEtOTQ5Ny0xNjNmYmNiMzZlODciCiAgIEdJTVA6'
    b'QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAgR0lNUDpUaW1lU3RhbXA9'
    b'IjE2MTE0NTMxNjczNTQ0ODMiCiAgIEdJTVA6VmVyc2lvbj0iMi4xMC4yMiIKICAgZGM6Rm9y'
    b'bWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEiCiAgIHhtcDpDcmVhdG9y'
    b'VG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICAgPHJk'
    b'ZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICA8aXB0Y0V4dDpMb2Nh'
    b'dGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25TaG93bj4K'
    b'ICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNF'
    b'eHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3RyeUlkPgogICAgPHJkZjpC'
    b'YWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1NOkhpc3Rvcnk+CiAgICA8'
    b'cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlvbj0ic2F2ZWQiCiAgICAg'
    b'IHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNlSUQ9InhtcC5paWQ6YWI0'
    b'ZGU0ZGMtMjY5Mi00Y2EwLTlkMmItYTY1MjRlODlmNjZiIgogICAgICBzdEV2dDpzb2Z0d2Fy'
    b'ZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0OndoZW49IjIwMjEtMDEt'
    b'MjNUMTk6NTI6NDctMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAgPC94bXBNTTpIaXN0b3J5'
    b'PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1h'
    b'Z2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAgPHJkZjpTZXEvPgogICA8'
    b'L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRPd25lcj4KICAgIDxyZGY6'
    b'U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1czpMaWNlbnNvcj4KICAg'
    b'IDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRmOkRlc2NyaXB0aW9uPgog'
    b'PC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'CiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAog'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8++wq51AAAAAZiS0dEAP8A'
    b'/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UBGAE0LzOp0sgAAABiSURB'
    b'VFjD7ZTBCsAwCEO19Jv8/3N+yl03aOkYRHfIOwuGxGgmhBCCR74Z8iIB2z2D7ILfxGR3BLkS'
    b'4gAoyiJiZ/0jGidbc7qxHN1VmQCMGMHndpQd4Sxug//uEbW/YiGEEBeBXxoFzUN2OwAAAABJ'
    b'RU5ErkJggg==')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kTtIw1AUhv+mFUUqInZQcchQnSyIijhqFYpQIdQKrTqY3PQFTRqSFBdHwbXg4GOx6uDi'
    b'rKuDqyAIPkDc3JwUXaTEc5NCixgPHO7Hf89/OPdcQKiXmWaFxgFNt81UIi5msqti5ysC6KMc'
    b'REhmljEnSUn4xtc9VVLcxXgv/7o/o0fNWQwIiMSzzDBt4g3i6U3b4LxPHGFFWSU+Jx4zaUDi'
    b'R64rHr9xLrgs8J4RM52aJ44Qi4U2VtqYFU2NeIo4qmo69RcyHquctzhr5SprzslfGM7pK8tc'
    b'pxxGAotYggQRCqoooQwbMTp1Uiyk6D7u4x9y/RK5FHKVwMixgAo0yK4f/A9+79bKT054ncJx'
    b'oOPFcT5GgM5doFFznO9jx2mcAMFn4Epv+St1YOaT9FpLix4BvdvAxXVLU/aAyx1g4MmQTdmV'
    b'gpRCPg+8n9E3ZYH+W6B7zdtb8x6nD0CadpW8AQ4OgdEC9V73eXdX+97+rWnu7wfkq3Ju9vHP'
    b'mwAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAAd0SU1FB+UBEQEZ'
    b'N33nX/sAAAApSURBVDjLY2AYBejgPzU0/6eGzUQbwghVzEipd/5TIyz+UzMgRwE9AQCbdAv3'
    b'W4tGRgAAAABJRU5ErkJggg==')

